#!/usr/bin/env bash

# This script takes care of copying and code signing the Reveal Server XCFramework into your iOS application target.

# NOTE: This script is intended to be run from within an Xcode run script build phase, and won't work without the environment variables provided therein.

# If you want to inspect your app using Reveal in build configurations that are not the default "Debug" configuration, override the REVEAL_LOAD_FOR_CONFIGURATION environment variable with the full name of your desired configuration.
load_trigger=${REVEAL_LOAD_FOR_CONFIGURATION:-Debug}

if [ "${PLATFORM_NAME}" == *simulator ]; then
    echo "Reveal Server not copied into ${TARGET_NAME}: Targeted platform is simulated, and does not require it."
    exit 0
fi

if [ "${CONFIGURATION}" != "${load_trigger}" ]; then
    echo "Skipping Reveal Server integration for ${TARGET_NAME}: Current build configuration is not '${load_trigger}'."
    exit 0
fi

# Ensure that we have a valid REVEAL_SERVER_FILENAME environment variable, or fall back to the default shipped with the app.
REVEAL_SERVER_FILENAME=${REVEAL_SERVER_FILENAME:-"RevealServer.xcframework"}

# Ensure that we have a valid REVEAL_SERVER_PATH environment variable, or fall back to the default that we copy to the user's application support directory.
REVEAL_SERVER_PATH=${REVEAL_SERVER_PATH:-"${HOME}/Library/Application Support/Reveal/RevealServer/${REVEAL_SERVER_FILENAME}"}

# Populate a variable with the current code signing identity if it's available in the environment.
SIGNING_IDENTITY="${EXPANDED_CODE_SIGN_IDENTITY:-$CODE_SIGN_IDENTITY}"

# Populate a variable with the current code signing flags and options in the environment.
OTHER_CODE_SIGN_FLAGS=${OTHER_CODE_SIGN_FLAGS:-}

if [ -e "${REVEAL_SERVER_PATH}" ]; then
    APP_FRAMEWORKS_DIRECTORY="${CONFIGURATION_BUILD_DIR}/${FRAMEWORKS_FOLDER_PATH}"

    # Ensure that the application bundle's "Frameworks" directory exists.
    mkdir -p "${APP_FRAMEWORKS_DIRECTORY}"

    # Copy the XCFramework into place.
    ditto -v "${REVEAL_SERVER_PATH}" "${APP_FRAMEWORKS_DIRECTORY}/${REVEAL_SERVER_FILENAME}"

    # Re-sign the XCFramework using the application's details, or the kernel will refuse to load any of the bundled framework binaries.
    if [ -n "${SIGNING_IDENTITY}" ]; then
        # Sign the inner frameworks first.
        find "${APP_FRAMEWORKS_DIRECTORY}/${REVEAL_SERVER_FILENAME}" \
            -name "*.framework" \
            -exec codesign ${OTHER_CODE_SIGN_FLAGS} \
                --force \
                --sign "${SIGNING_IDENTITY}" \
                {} \;

        # Now sign the wrapper XCFramework.
        xcrun codesign ${OTHER_CODE_SIGN_FLAGS} \
                --force \
                --sign "${SIGNING_IDENTITY}" \
                "${APP_FRAMEWORKS_DIRECTORY}/${REVEAL_SERVER_FILENAME}"
    fi

    echo "${REVEAL_SERVER_FILENAME} is included in this build, and has been copied to $APP_FRAMEWORKS_DIRECTORY"

    LLDB_INIT_FILE=~/.lldbinit
    LLDB_INIT_MAGIC_STRING="### Reveal LLDB commands support"

    if [ ! -e "${LLDB_INIT_FILE}" ] || ! grep -q "${LLDB_INIT_MAGIC_STRING}" "${LLDB_INIT_FILE}"; then
        echo "Note: it looks like Reveal Server's debugger commands are not installed. Please refer to 'Loading the Reveal Server via an Xcode Breakpoint' section of the Integration Guide for information about loading Reveal Server included in this build."
    fi

    # Now we need to attempt to insert the NSBonjourServices array into the app's Info.plist. It's OK if this fails due to the key already existing.
    plutil -insert NSBonjourServices -xml '<array/>' "${CONFIGURATION_BUILD_DIR}/${INFOPLIST_PATH}" || true

    # Now insert Reveal's Bonjour details into the NSBonjourServices array.
    plutil -insert NSBonjourServices.0 -string "_reveal._tcp" "${CONFIGURATION_BUILD_DIR}/${INFOPLIST_PATH}"

    echo "An NSBonjourServices entry for Reveal (_reveal._tcp) has been added to ${INFOPLIST_PATH}"

    echo "Reveal Server has been successfully integrated into ${TARGET_NAME}."
else
  echo "Reveal Server not integrated into ${TARGET_NAME}: ${REVEAL_SERVER_FILENAME} could not be found."
fi
